---
name: Feature Request
about: Suggest an idea for a new feature or enhancement for radish
title: ''
labels: 'feature request'
assignees: ''

---

**Important notices**
Before you add a new request, we ask you kindly to acknowledge the following:

[-] I have read the contributing guide lines at https://github.com/radish-bdd/radish/blob/master/.github/CONTRIBUTING.md

[-] I have read and respect the code of conduct at https://github.com/radish-bdd/radish/blob/master/.github/CODE_OF_CONDUCT.md

[-] I have searched the existing issues and I'm convinced that mine is new.

**Is your Feature Request related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Additional context**
Add any other context or screenshots about the Feature Request here.
